CHECK_INTERVAL = 20
DEPLOY_LANGUAGE = "cn"
LAIPVT_BASE_DIR = "/usr/local/laipvt"
CHECK_FILE = "/usr/local/laipvt/check_result.yaml"
PRE_CHECK_RESULT_FILE = "/usr/local/laipvt/.precheck_result.yaml"
PORT_MAP = "/usr/local/laipvt/ports.yaml"
STATUS_FILE = "/usr/local/laipvt/.deploy_status"

# LOG
LAIPVT_LOG_PATH = "/usr/local/laipvt/logs"
LAIPVT_LOG_NAME = "laipvt.log"
LAIPVT_LOG_LEVEL = "DEBUG"
LOG_TO_TTY = True
